//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.


// Definition of low level function used in sci_CLx_* files
extern "C"
{
/* ==================================================================== */
#include "api_scilab.h"
#include "Scierror.h"
#include "MALLOC.h"
#include <localization.h>
#include "CLx_gw_util.h"

/* ==================================================================== */
int getInputMatrixDouble(void *pvApiCtx, int argPos, double **pdValues, char *fname)
{
    int *piAddressVar = NULL;
    SciErr sciErr;
    int iRows = 0;
    int iCols = 0;

    sciErr = getVarAddressFromPosition(pvApiCtx, argPos, &piAddressVar);
    if (sciErr.iErr)
    {
        printError(&sciErr, 0);
        return 1;
    }
    if (!isDoubleType(pvApiCtx, piAddressVar))
    {
        Scierror(999, "%s: Wrong type for input argument #%d: A double expected.\n", fname, argPos);
        return 1;
    }
    sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar, &iRows, &iCols, pdValues);
    if (sciErr.iErr)
    {
        printError(&sciErr, 0);
        return sciErr.iErr;
    }
    return 0;
}

int getInputInteger(void *pvApiCtx, int argPos, int *piValue, char *fname)
{
    int *piAddressVar = NULL;
    SciErr sciErr;

    sciErr = getVarAddressFromPosition(pvApiCtx, argPos, &piAddressVar);
    if (sciErr.iErr)
    {
        printError(&sciErr, 0);
        return 1;
    }
    if (!isIntegerType(pvApiCtx, piAddressVar))
    {
        Scierror(999, "%s: Wrong type for input argument #%d: An integer expected.\n", fname, argPos);
        return 1;
    }
    if (getScalarInteger32(pvApiCtx, piAddressVar, piValue))
    {
        Scierror(999, "%s: Wrong size for input argument #%d: A scalar expected.\n", fname, argPos);
        return 1;
    }
    return 0;
}

int setOutputMatrixDouble(void *pvApiCtx, int argPos, double *pdValues, int iRows, int iCols, char *fname)
{
    SciErr sciErr;
    sciErr = createMatrixOfDouble(pvApiCtx, nbInputArgument(pvApiCtx) + argPos, iRows, iCols, pdValues);
    if (sciErr.iErr)
    {
        printError(&sciErr, 0);
        return sciErr.iErr;
    }
    AssignOutputVariable(pvApiCtx, argPos) = nbInputArgument(pvApiCtx) + argPos;
    return 0;
}

int setOutputMatrixInteger(void *pvApiCtx, int argPos, int *piValues, int iRows, int iCols, char *fname)
{
    SciErr sciErr;
    sciErr = createMatrixOfInteger32(pvApiCtx, nbInputArgument(pvApiCtx) + argPos, iRows, iCols, piValues);
    if (sciErr.iErr)
    {
        printError(&sciErr, 0);
        return sciErr.iErr;
    }
    AssignOutputVariable(pvApiCtx, argPos) = nbInputArgument(pvApiCtx) + argPos;
    return 0;
}

int setOutputInteger(void *pvApiCtx, int argPos, int iValue, char *fname)
{
    if (createScalarInteger32(pvApiCtx, nbInputArgument(pvApiCtx) + argPos, iValue))
    {
        Scierror(999, _("%s: Memory allocation error.\n"), fname);
        return 1;
    }
    AssignOutputVariable(pvApiCtx, argPos) = nbInputArgument(pvApiCtx) + argPos;
    return 0;
}

int setOutputDouble(void *pvApiCtx, int argPos, double dValue, char *fname)
{
    if (createScalarDouble(pvApiCtx, nbInputArgument(pvApiCtx) + argPos, dValue))
    {
        Scierror(999, _("%s: Memory allocation error.\n"), fname);
        return 1;
    }
    AssignOutputVariable(pvApiCtx, argPos) = nbInputArgument(pvApiCtx) + argPos;
    return 0;
}

} /* extern "C" */
/* ==================================================================== */

