//  Copyright (c) CNES  2008
//
//  This software is part of CelestLab, a CNES toolbox for Scilab
//
//  This software is governed by the CeCILL license under French law and
//  abiding by the rules of distribution of free software.  You can  use,
//  modify and/ or redistribute the software under the terms of the CeCILL
//  license as circulated by CEA, CNRS and INRIA at the following URL
//  'http://www.cecill.info'.

package fr.cnes.celestlab.celestlabx.generic;


/** 
 * Class Informations
 * This class stores information that be suited for several uses: 
 * status (usually: 0 = OK, negative => error, positive => warning) 
 * message (string)
 * additional information (array of strings)
 */
public class Information
{
	private int _status;
	private String _msg;
	private String[] _info;

	
	/**
	 * Default constructor
	 */
	public Information()
	{
		_status = 0;
		_msg = "";
		_info = new String[0]; 
	}

	/**
	 * Constructor
	 * @param status status 
	 * @param msg message
	 */
	public Information(int status, String msg)
	{
		_status = status;
		_msg = new String(msg);
		_info = new String[0]; 
	}

	/**
	 * Constructor (variant)
	 * @param status status 
	 * @param msg message
	 * @param info additional information
	 */
	public Information(int status, String msg, String[] info)
	{
		_status = status;
		_msg = new String(msg);
		_info = info.clone(); 
	}

	/**
	 * Returns the status value
	 * @return the status value {@link Integer} : 0 (OK), 1 (Warning), -1 (Error)
	 */
	public int getStatus()
	{
		return _status;
	}

	/**
	 * Returns the message value
	 * @return the message value {@link String}
	 */
	public String getMessage()
	{
		return new String(_msg);
	}

	/**s
	 * Returns the info value
	 * @return the info value
	 */
	public String[] getInfo() 
	{
		return _info.clone();
	}


}
